define(["require", "exports", "@essential-projects/errors_ts"], function (require, exports, errors_ts_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    class ExternalTaskApiInternalAccessor {
        constructor(externalApiService) {
            this.externalApiService = undefined;
            this.externalApiService = externalApiService;
        }
        async fetchAndLockExternalTasks(identity, workerId, topicName, maxTasks, longPollingTimeout, lockDuration) {
            this.ensureIsAuthorized(identity);
            return this
                .externalApiService
                .fetchAndLockExternalTasks(identity, workerId, topicName, maxTasks, longPollingTimeout, lockDuration);
        }
        async extendLock(identity, workerId, externalTaskId, additionalDuration) {
            this.ensureIsAuthorized(identity);
            return this.externalApiService.extendLock(identity, workerId, externalTaskId, additionalDuration);
        }
        async handleBpmnError(identity, workerId, externalTaskId, errorCode) {
            this.ensureIsAuthorized(identity);
            return this.externalApiService.handleBpmnError(identity, workerId, externalTaskId, errorCode);
        }
        async handleServiceError(identity, workerId, externalTaskId, errorMessage, errorDetails) {
            this.ensureIsAuthorized(identity);
            return this.externalApiService.handleServiceError(identity, workerId, externalTaskId, errorMessage, errorDetails);
        }
        async finishExternalTask(identity, workerId, externalTaskId, payload) {
            this.ensureIsAuthorized(identity);
            return this.externalApiService.finishExternalTask(identity, workerId, externalTaskId, payload);
        }
        ensureIsAuthorized(identity) {
            // Note: When using an external accessor, this check is performed by the ConsumerApiHttp module.
            // Since that component is bypassed by the internal accessor, we need to perform this check here.
            const authTokenNotProvided = !identity || typeof identity.token !== 'string';
            if (authTokenNotProvided) {
                throw new errors_ts_1.UnauthorizedError('No auth token provided!');
            }
        }
    }
    exports.ExternalTaskApiInternalAccessor = ExternalTaskApiInternalAccessor;
});
//# sourceMappingURL=internal_accessor.js.map