"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const consumer_api_contracts_1 = require("@process-engine/consumer_api_contracts");
class ExternalTaskApiExternalAccessor {
    constructor(httpClient) {
        this.baseUrl = 'api/external_task/v1';
        this.httpClient = undefined;
        this.httpClient = httpClient;
    }
    async fetchAndLockExternalTasks(identity, workerId, topicName, maxTasks, longPollingTimeout, lockDuration) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = consumer_api_contracts_1.restSettings.paths.fetchAndLockExternalTasks;
        url = this.applyBaseUrl(url);
        const payload = new consumer_api_contracts_1.DataModels.ExternalTask.FetchAndLockRequestPayload(workerId, topicName, maxTasks, longPollingTimeout, lockDuration);
        const httpResponse = await this
            .httpClient
            // eslint-disable-next-line max-len
            .post(url, payload, requestAuthHeaders);
        return httpResponse.result;
    }
    async extendLock(identity, workerId, externalTaskId, additionalDuration) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = consumer_api_contracts_1.restSettings.paths.extendExternalTaskLock
            .replace(consumer_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new consumer_api_contracts_1.DataModels.ExternalTask.ExtendLockRequestPayload(workerId, additionalDuration);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    async handleBpmnError(identity, workerId, externalTaskId, errorCode) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = consumer_api_contracts_1.restSettings.paths.finishExternalTaskWithBpmnError
            .replace(consumer_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new consumer_api_contracts_1.DataModels.ExternalTask.HandleBpmnErrorRequestPayload(workerId, errorCode);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    async handleServiceError(identity, workerId, externalTaskId, errorMessage, errorDetails) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = consumer_api_contracts_1.restSettings.paths.finishExternalTaskWithServiceError
            .replace(consumer_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new consumer_api_contracts_1.DataModels.ExternalTask.HandleServiceErrorRequestPayload(workerId, errorMessage, errorDetails);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    async finishExternalTask(identity, workerId, externalTaskId, results) {
        const requestAuthHeaders = this.createRequestAuthHeaders(identity);
        let url = consumer_api_contracts_1.restSettings.paths.finishExternalTask
            .replace(consumer_api_contracts_1.restSettings.params.externalTaskId, externalTaskId);
        url = this.applyBaseUrl(url);
        const payload = new consumer_api_contracts_1.DataModels.ExternalTask.FinishExternalTaskRequestPayload(workerId, results);
        await this.httpClient.post(url, payload, requestAuthHeaders);
    }
    createRequestAuthHeaders(identity) {
        const noAuthTokenProvided = !identity || typeof identity.token !== 'string';
        if (noAuthTokenProvided) {
            return {};
        }
        const requestAuthHeaders = {
            headers: {
                Authorization: `Bearer ${identity.token}`,
            },
        };
        return requestAuthHeaders;
    }
    applyBaseUrl(url) {
        return `${this.baseUrl}${url}`;
    }
}
exports.ExternalTaskApiExternalAccessor = ExternalTaskApiExternalAccessor;
//# sourceMappingURL=external_accessor.js.map